@@ -1,13 +1,45 @@
 #include "myheader.h"
-/*x is n by nbeta matrix
-beta has length nbeta
-Umat is myq by m matrix, one COLUMN of Umat used at a time. Umat must be the R mat transposed 
-z is n by myq matrix
-pee is the vector of sampling proportions (usually 1/3, 1/3, 1/3)
-nps is the length of pee (3 for now, maybe more if imp sampling distrib changes)
-ntrials is a vec of ints with length equal to length(y)
+/*problem with gamma and squaretop causing issue with numsum: overflow/underflow*/
+
+/*
+ gamma: scalar
+ thing: scalar
+ squaretop: vector length m
+ numsum: vector of length (nbeta + T)^2 = npar^2
+ y: vector of length n
+ Umat: myq by m matrix.  one COLUMN of Umat used at a time. Umat must be the R mat transposed
+ myq: total number of random effects (q). scalar. 120 for salamanders.
+ m: Monte Carlo sample size. scalar.
+scalar.
+ x: n by nbeta matrix
+ n: sample size. scalar. 
+ nbeta: scalar equal to the dim of beta (number of fixed effects)
+ beta: vector length nbeta
+ z: n by myq matrix
+ Dinvfornu: square, symmetric matrix. myq x myq. D is variance matrix.
+ logdetDinvfornu: scalar equal to the log determinant for D's inverse
+ family_glmm:  int scalar
+ Dstarinv: square, symmetric matrix. myq x myq. Dstar is variance matrix from PQL.
+ logdetDstarinv: scalar equal to the log determinant for Dstar's inverse
+ ustar: vector containing PQL predictions for random effects. length = myq.
+ Sigmuhinv: variance matrix for normal used in importance sampling dist. myq x myq.
+ logdetSigmuhinv: scalar. 
+ pee: vector of length nps. vector of sampling proportions (usually 1/3, 1/3, 1/3)
+ nps: scalar
+ T: scalar equal to the number of variance components
+ nrandom: vector of length T. 
+ meow: vector of ints. length T+1. tells us which random effects go with each variance.
+ nu: vector of length T. equals the variance components.
+ zeta: int equal to the df for the t distrib. (p 13 of design doc)
+ tconst: scalar. (p13 of design doc, equation 59)
+ ntrials: is a vec of ints with length equal to n
+ lfuval: scalar
+ lfyuval: scalar
+ wts: weights for the observations (to calculate weighted likelihood).  vector length n.
+
+ 
 */
-void mcsec(double *gamma, double *thing, double *squaretop, double *numsum, double *y, double *Umat, int *myq, int *m, double *x, int *n, int *nbeta, double *beta, double *z, double *Dinvfornu, double *logdetDinvfornu, int *family_glmm, double *Dstarinv, double *logdetDstarinv, double *ustar, double *Sigmuhinv, double *logdetSigmuhinv, double *pee, int *nps, int *T, int *nrandom, int *meow, double *nu, int *zeta, double *tconst,  int *ntrials)
+void mcsec(double *gamma, double *thing, double *squaretop, double *numsum, double *y, double *Umat, int *myq, int *m, double *x, int *n, int *nbeta, double *beta, double *z, double *Dinvfornu, double *logdetDinvfornu, int *family_glmm, double *Dstarinv, double *logdetDstarinv, double *ustar, double *Sigmuhinv, double *logdetSigmuhinv, double *pee, int *nps, int *T, int *nrandom, int *meow, double *nu, int *zeta, double *tconst,  int *ntrials, double *lfuval, double *lfyuval, double *wts)
 {
 	double *Uk = Calloc(*myq, double);
 	int Uindex = 0;
@@ -24,8 +56,8 @@ void mcsec(double *gamma, double *thing, double *squaretop, double *numsum, doub
 	double tempmax = 1.0;
 	double *lfutwidpieces = Calloc(*nps,double);
 	double diffs = 0.0;
-	double lfuval = 1.1;
-	double lfyuval = 1.1;
+	/*double lfuval = 1.1;
+	double lfyuval = 1.1;*/
 	double lfutwid = 1.1;
 	double *b = Calloc(*m,double);
 	double a = 0.0;
@@ -45,10 +77,10 @@ void mcsec(double *gamma, double *thing, double *squaretop, double *numsum, doub
 		addvec(xbeta, zu, n, eta);
 
 		/*log f_theta(u_k) goes into lfuval*/
-		distRandGenC(Dinvfornu, logdetDinvfornu, myq, Uk, qzeros, &lfuval); 
+		distRandGenC(Dinvfornu, logdetDinvfornu, myq, Uk, qzeros, lfuval); /*&*/
 
 		/* log f_theta(y|u_k) value goes into lfyuval */
-		elval(y, n, nbeta, eta, family_glmm, ntrials, &lfyuval);
+		elval(y, n, nbeta, eta, family_glmm, ntrials, wts, lfyuval); /*&*/
 
 		/* value of log f~_theta(u_k) 
 		first calculate value of log f~_theta(u_k) for 3 distribs used 
@@ -81,12 +113,13 @@ void mcsec(double *gamma, double *thing, double *squaretop, double *numsum, doub
 		}
 		lfutwid = log(lfutwid)+tempmax; /* finishes lfutwid calc */
 
-		b[k] = lfuval+lfyuval-lfutwid;
+		b[k] = *lfuval+ *lfyuval-lfutwid;
 
 		if(k==0){a = b[k];}
 		if(b[k]>a){a = b[k];}
 
-		squaretop[k] = exp(2*lfuval + 2*lfyuval - 2*lfutwid);
+		squaretop[k] = exp(2* *lfuval + 2* *lfyuval - 2*lfutwid); /*also exp(2*b[k])?*/
+        /*tryfix[k] = b[k];*/
 	}
 
 	Free(lfutwidpieces);
@@ -99,7 +132,8 @@ void mcsec(double *gamma, double *thing, double *squaretop, double *numsum, doub
 	Free(b);
 
 	/* Calculate gamma */
-	gamma[0] = exp(a) * *thing / *m; 
+	gamma[0] = exp(a) * *thing / *m;
+    /*gamma[0] = exp(a - log(*m) +log(*thing));*/
 
 
 /* now going to do second loop, for numerator */
@@ -133,7 +167,7 @@ void mcsec(double *gamma, double *thing, double *squaretop, double *numsum, doub
 		distRand3C(nu, qzeros, T, nrandom, meow, Uk, lfugradient, lfuhess);
 
 		/* calculate gradient and hessian log f_theta(y|u_k) */
-		elGH(y, x, n, nbeta, eta, family_glmm, ntrials, lfyugradient, lfyuhess);
+		elGH(y, x, n, nbeta, eta, family_glmm, ntrials, wts, lfyugradient, lfyuhess);
 
 		/*now I have lfugradient and lfyugradient*/
 
